---------------Begin Copyright - Do not add comments here-----------------
--
-- Licensed Materials - Property of IBM
-- 5698-APM
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
--		
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-------------End Copyright------------------------------------------------

--------------------------------------------------------------
-- Fills in the table TWG.Msmt with response time measurements
--
-- Source Datasource : TWH_CDW
-- Target Datasource : TWH_CDW
--
--------------------------------------------------------------

--------------------------------------------------------------
--
-- IY51493,JMG,20031218 : Added DISTINCT function before 
-- SELECTS for INSERTS
--
--------------------------------------------------------------

-- Fills in the staging table with components and measurements 
-- applicable to each of them

--#EXECUTE_AT_TARGET
drop table apf.stage_comp_msmtrul_copy;

--#EXECUTE_AT_TARGET
create table apf.stage_comp_msmtrul_copy like apf.stage_comp_msmtrul;

--#INSERT_INTO_TARGET
insert into apf.stage_comp_msmtrul_copy
select
    t1.comp_id,
    t2.msmttyp_id
from
    twg.comp t1,
    twg.msmttyp t2,
    twg.comptyp t3,
    twg.msmtrul t4
where
    t1.comptyp_cd = t3.comptyp_cd and
    t3.comptyp_cd = 'TAPM_TX' and
    t3.comptyp_cd = t4.comptyp_cd and
    t4.msmttyp_id = t2.msmttyp_id
group by
    t1.comp_id, t2.msmttyp_id
;

-- Temporary table to contain response time min values
declare global temporary table temp_msmt_rtmin(
    comp_id integer,
    msmttyp_id integer,
    msmt_strt_dt date,
    msmt_strt_tm time,
    msmt_min_val float
)
with replace on commit preserve rows not logged
;

-- The temporary table temp_msmt_rtmin is filled in with 24 different insert ops

-- table: session.temp_msmt_rtmin   time: 00:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+0*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('00:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_00 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 01:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+1*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('01:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_01 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 02:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+2*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('02:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_02 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 03:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+3*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('03:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_03 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 04:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+4*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('04:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_04 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 05:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+5*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('05:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_05 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 06:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+6*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('06:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_06 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 07:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+7*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('07:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_07 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 08:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+8*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('08:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_08 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 09:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+9*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('09:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_09 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 10:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+10*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('10:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_10 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 11:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+11*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('11:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_11 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name    
)
;

-- table: session.temp_msmt_rtmin   time: 12:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+12*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('12:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_12 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 13:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+13*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('13:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_13 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 14:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+14*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('14:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_14 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 15:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+15*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('15:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_15 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 16:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+16*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('16:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_16 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 17:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+17*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('17:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_17 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 18:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+18*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('18:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_18 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 19:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+19*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('19:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_19 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 20:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+20*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('20:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_20 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 21:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+21*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('21:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_21 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 22:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+22*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('22:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_22 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmin   time: 23:00
insert into session.temp_msmt_rtmin
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+23*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('23:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_23 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_min'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- Temporary table to contain response time max values
declare global temporary table temp_msmt_rtmax(
    comp_id integer,
    msmttyp_id integer,
    msmt_strt_dt date,
    msmt_strt_tm time,
    msmt_max_val float
) 
with replace on commit preserve rows not logged
;

-- The temporary table temp_msmt_rtmax is filled in with 24 different insert ops

-- table: session.temp_msmt_rtmax   time: 00:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+0*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('00:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_00 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 01:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+1*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('01:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_01 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 02:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+2*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('02:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_02 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 03:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+3*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('03:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_03 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 04:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+4*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('04:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_04 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 05:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+5*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('05:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_05 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
);

-- table: session.temp_msmt_rtmax   time: 06:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+6*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('06:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_06 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 07:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+7*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('07:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_07 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 08:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+8*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('08:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_08 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 09:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+9*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('09:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_09 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 10:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+10*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('10:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_10 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 11:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+11*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('11:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_11 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 12:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+12*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('12:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_12 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 13:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+13*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('13:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_13 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 14:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+14*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('14:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_14 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 15:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+15*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('15:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_15 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 16:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+16*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('16:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_16 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 17:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+17*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('17:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_17 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 18:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+18*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('18:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_18 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 19:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+19*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('19:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_19 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 20:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+20*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('20:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_20 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 21:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+21*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('21:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_21 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 22:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+22*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('22:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_22 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtmax   time: 23:00
insert into session.temp_msmt_rtmax
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+23*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('23:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_23 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_max'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- Temporary table to contain response time avg values
declare global temporary table temp_msmt_rtavg(
    comp_id integer,
    msmttyp_id integer,
    msmt_strt_dt date,
    msmt_strt_tm time,
    msmt_avg_val float
) 
with replace on commit preserve rows not logged
;

-- The temporary table temp_msmt_rtavg is filled in with 24 different insert ops

-- table: session.temp_msmt_rtavg   time: 00:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+0*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('00:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_00 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 01:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+1*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('01:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_01 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 02:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+2*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('02:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_02 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 03:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+3*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('03:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_03 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 04:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+4*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('04:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_04 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 05:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+5*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('05:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_05 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 06:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+6*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('06:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_06 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 07:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+7*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('07:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_07 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 08:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+8*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('08:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_08 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 09:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+9*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('09:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_09 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 10:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+10*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('10:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_10 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 11:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+11*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('11:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_11 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 12:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+12*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('12:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_12 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 13:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+13*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('13:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_13 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 14:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+14*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('14:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_14 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 15:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+15*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('15:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_15 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 16:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+16*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('16:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_16 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 17:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+17*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('17:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_17 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 18:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+18*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('18:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_18 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 19:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+19*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('19:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_19 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 20:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+20*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('20:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_20 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 21:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+21*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('21:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_21 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 22:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+22*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('22:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_22 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_rtavg   time: 23:00
insert into session.temp_msmt_rtavg
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+23*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('23:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_23 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'rt_avg'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- Temporary table to contain successful transactions count
declare global temporary table temp_msmt_ntxgood(
    comp_id integer,
    msmttyp_id integer,
    msmt_strt_dt date,
    msmt_strt_tm time,
    msmt_smpl_cnt integer
) 
with replace on commit preserve rows not logged
;

-- The temporary table temp_msmt_ntxgood is filled in with 24 different insert ops

-- table: session.temp_msmt_ntxgood   time: 00:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+0*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('00:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_00 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 01:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+1*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('01:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_01 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 02:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+2*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('02:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_02 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 03:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+3*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('03:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_03 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 04:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+4*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('04:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_04 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 05:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+5*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('05:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_05 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 06:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+6*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('06:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_06 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 07:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+7*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('07:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_07 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 08:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+8*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('08:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_08 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 09:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+9*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('09:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_09 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 10:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+10*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('10:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_10 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 11:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+11*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('11:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_11 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 12:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+12*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('12:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_12 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 13:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+13*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('13:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_13 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 14:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+14*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('14:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_14 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 15:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+15*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('15:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_15 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 16:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+16*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('16:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_16 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 17:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+17*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('17:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_17 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 18:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+18*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('18:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_18 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 19:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+19*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('19:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_19 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 20:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+20*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('20:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_20 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 21:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+21*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('21:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_21 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 22:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+22*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('22:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_22 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxgood   time: 23:00
insert into session.temp_msmt_ntxgood
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+23*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('23:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_23 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_good'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- Temporary table to contain aborted transaction count
declare global temporary table temp_msmt_ntxabort(
    comp_id integer,
    msmttyp_id integer,
    msmt_strt_dt date,
    msmt_strt_tm time,
    msmt_txabort_cnt integer
) 
with replace on commit preserve rows not logged
;

-- The temporary table temp_msmt_ntxabort is filled in with 24 different insert ops

-- table: session.temp_msmt_ntxabort   time: 00:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+0*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('00:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_00 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 01:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+1*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('01:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_01 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 02:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+2*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('02:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_02 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 03:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+3*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('03:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_03 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 04:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+4*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('04:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_04 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 05:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+5*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('05:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_05 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 06:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+6*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('06:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_06 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 07:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+7*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('07:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_07 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 08:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+8*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('08:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_08 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 09:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+9*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('09:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_09 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 10:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+10*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('10:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_10 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 11:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+11*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('11:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_11 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 12:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+12*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('12:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_12 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 13:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+13*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('13:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_13 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 14:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+14*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('14:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_14 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 15:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+15*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('15:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_15 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 16:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+16*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('16:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_16 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 17:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+17*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('17:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_17 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 18:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+18*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('18:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_18 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 19:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+19*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('19:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_19 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 20:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+20*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('20:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_20 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 21:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+21*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('21:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_21 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 22:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+22*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('22:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_22 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxabort   time: 23:00
insert into session.temp_msmt_ntxabort
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+23*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('23:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_23 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_aborted'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- Temporary table to contain failed transaction count
declare global temporary table temp_msmt_ntxfailed(
    comp_id integer,
    msmttyp_id integer,
    msmt_strt_dt date,
    msmt_strt_tm time,
    msmt_txfailed_cnt integer
) 
with replace on commit preserve rows not logged
;

-- The temporary table temp_msmt_ntxfailed is filled in with 24 different insert ops

-- table: session.temp_msmt_ntxfailed   time: 00:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+0*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('00:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_00 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 01:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+1*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('01:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_01 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 02:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+2*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('02:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_02 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 03:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+3*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('03:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_03 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 04:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+4*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('04:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_04 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 05:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+5*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('05:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_05 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 06:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+6*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('06:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_06 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 07:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+7*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('07:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_07 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 08:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+8*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('08:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_08 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 09:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+9*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('09:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_09 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 10:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+10*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('10:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_10 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 11:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+11*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('11:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_11 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 12:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+12*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('12:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_12 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 13:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+13*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('13:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_13 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 14:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+14*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('14:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_14 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 15:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+15*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('15:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_15 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 16:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+16*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('16:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_16 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 17:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+17*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('17:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_17 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 18:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+18*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('18:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_18 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 19:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+19*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('19:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_19 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 20:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+20*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('20:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_20 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 21:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+21*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('21:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_21 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 22:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+22*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('22:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_22 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- table: session.temp_msmt_ntxfailed   time: 23:00
insert into session.temp_msmt_ntxfailed
(
    select distinct
        a.comp_id,
        c.msmttyp_id,    
        DATE('01/01/1970') + INTEGER((d.dt_stamp+(e.host_time_zone+23*60)*60)/86400) DAYS as msmt_strt_dt,
        (TIME('23:00') + e.host_time_zone MINUTES) as msmt_strt_tm,
        d.value_23 as msmt_min_val
    from
        apf.stage_comp_msmtrul_copy a,
        apf.stage_id_info_comp_copy b,
        twg.msmttyp c,
        apf.stage_metricdata32_copy d,
        apf.stage_host_attr_copy e,
        apf.stage_id_info_copy f
    where
        a.comp_id = b.tx_comp_id
        and a.msmttyp_id = c.msmttyp_id
        and c.msmttyp_nm = 'ResponseTime'
        and b.tx_class_id = d.tx_class_id
        and d.metric_name = 'n_tx_failed'
        and d.tx_class_id = f.tx_class_id
        and e.host_name = f.host_name
)
;

-- Fills in table twg.msmt with response time measurement
insert into twg.msmt
    (
        msmt_id,
        comp_id,
        msmttyp_id,
        tmsum_cd,
        msmt_strt_dt,
        msmt_strt_tm,
        msmt_min_val,
        msmt_max_val,
        msmt_avg_val,
        msmt_smpl_cnt,
        msmt_err_cnt
    )
select
    0,
    a.comp_id,
    a.msmttyp_id,
    'H' as tmsum_cd,
    a.msmt_strt_dt,
    a.msmt_strt_tm,
    a.msmt_min_val,
    b.msmt_max_val,
    c.msmt_avg_val,
    case
      when d.msmt_smpl_cnt = 0 then null
      else d.msmt_smpl_cnt
    end as msmt_smpl_cnt,
    case
      when (e.msmt_txabort_cnt + f.msmt_txfailed_cnt) = 0 then null
      else (e.msmt_txabort_cnt + f.msmt_txfailed_cnt)
    end as msmt_err_cnt
from
    session.temp_msmt_rtmin a,
    session.temp_msmt_rtmax b,
    session.temp_msmt_rtavg c,
    session.temp_msmt_ntxgood d,
    session.temp_msmt_ntxabort e,
    session.temp_msmt_ntxfailed f
where
    a.comp_id = b.comp_id
    and a.comp_id = c.comp_id
    and a.comp_id = d.comp_id
    and a.comp_id = e.comp_id
    and a.comp_id = f.comp_id
    and b.comp_id = c.comp_id
    and b.comp_id = d.comp_id
    and b.comp_id = e.comp_id
    and b.comp_id = f.comp_id
    and c.comp_id = d.comp_id
    and c.comp_id = e.comp_id
    and c.comp_id = f.comp_id
    and d.comp_id = e.comp_id
    and d.comp_id = f.comp_id
    and e.comp_id = f.comp_id
    and a.msmt_strt_dt = b.msmt_strt_dt
    and a.msmt_strt_dt = c.msmt_strt_dt
    and a.msmt_strt_dt = d.msmt_strt_dt
    and a.msmt_strt_dt = e.msmt_strt_dt
    and a.msmt_strt_dt = f.msmt_strt_dt
    and b.msmt_strt_dt = c.msmt_strt_dt
    and b.msmt_strt_dt = d.msmt_strt_dt
    and b.msmt_strt_dt = e.msmt_strt_dt
    and b.msmt_strt_dt = f.msmt_strt_dt
    and c.msmt_strt_dt = d.msmt_strt_dt
    and c.msmt_strt_dt = e.msmt_strt_dt
    and c.msmt_strt_dt = f.msmt_strt_dt
    and d.msmt_strt_dt = e.msmt_strt_dt
    and d.msmt_strt_dt = f.msmt_strt_dt
    and e.msmt_strt_dt = f.msmt_strt_dt
    and a.msmt_strt_tm = b.msmt_strt_tm
    and a.msmt_strt_tm = c.msmt_strt_tm
    and a.msmt_strt_tm = d.msmt_strt_tm
    and a.msmt_strt_tm = e.msmt_strt_tm
    and a.msmt_strt_tm = f.msmt_strt_tm
    and b.msmt_strt_tm = c.msmt_strt_tm
    and b.msmt_strt_tm = d.msmt_strt_tm
    and b.msmt_strt_tm = e.msmt_strt_tm
    and b.msmt_strt_tm = f.msmt_strt_tm
    and c.msmt_strt_tm = d.msmt_strt_tm
    and c.msmt_strt_tm = e.msmt_strt_tm
    and c.msmt_strt_tm = f.msmt_strt_tm
    and d.msmt_strt_tm = e.msmt_strt_tm
    and d.msmt_strt_tm = f.msmt_strt_tm
    and e.msmt_strt_tm = f.msmt_strt_tm
;
